# IKontist
Fetch transactions from Kontist

## What does it do?
We provide 
1. a command line tool to export transactions (currently QIF and JSON) and
2. a JavaScript API to Kontist.

Please note that this project is in a early stage and support is welcome.

## How to use the CLI
### Prerequisites
* [node](https://nodejs.org) and npm installed
* Add your Kontist username and password either to ENVs called `KONTIST_USER` and `KONTIST_PASSWORD` or a .env file (just rename `.env-template` to `.env` and replace the credentials).

### Examples
```bash
node cli.js transactions json
```

will return
```
[
    {
        "id": 1234,
        "from": null,
        "to": 1234,
        "amount": 1234,
        "type": null,
        "meta": null,
        "figo_id": null,
        "checksum": "xxx",
        "pending_from": null,
        "user_id": 1234,
        "date": "2017-08-02T00:00:00.000Z",
        "category": "vat19",
        "name": "Example GmbH",
        "iban": "DE123456...",
        "purpose": "RNr. ABC",
        "solaris_id": "xxx",
        "debitoor_invoice_id": null,
        "debitoor_invoice_number": null,
        "wirecard_last_attempt_date": null,
        "wirecard_success_date": null,
        "wirecard_unique_request_id": "xxx",
        "e2e_id": "xxx",
        "debug_only_raw_booking": {
            "id": "xxx",
            "creation_date": "2017-08-02",
            "valuta_date": "2017-08-02",
            "booking_date": "2017-08-02",
            "booking_type": "SEPA_CREDIT_TRANSFER",
            "amount": {
                "value": 8199,
                "unit": "cents",
                "currency": "EUR"
            },
            "description": "RNr. ABC",
            "recipient_bic": "SOBKDEBB",
            "recipient_iban": null,
            "recipient_name": "xxx",
            "sender_bic": "xxx",
            "sender_iban": "xxx",
            "sender_name": "Example GmbH",
            "end_to_end_id": "xxx",
            "creditor_identifier": null,
            "mandate_reference": null,
            "transaction_id": null,
            "return_transaction_id": null,
            "sepa_return_code": null,
            "sepa_return_reason": null,
            "sepa_return_reason_definition": null
        },
        "booking_date": "2017-08-02T00:00:00.000Z",
        "valuta_date": "2017-08-02T00:00:00.000Z",
        "booking_type": "SEPA_CREDIT_TRANSFER",
        "source": "solaris",
        "wirecard_processor_message_state": null,
        "wirecard_processed_date": null,
        "wirecard_booking_type": null,
        "wirecard_booking_status": null,
        "createdAt": "2017-08-02T06:20:35.178Z",
        "updatedAt": "2017-08-02T06:31:52.486Z",
        "deletedAt": null
    },
    ...
]
```

```bash
node cli.js transactions qif
```

will return
```
!Type:Bank
D8/2/2017
T8199
PExample GmbH
MRNr. ABC
^
D8/2/2017
T2142
PExample
Mdescription
^
```

So an easy way to create a qif export would be:
```bash
node cli.js transactions qif > my-account.qif
```

## How to use the API
Please have a look at the `kontist-client.js`. Currently it provides methods for the following endpoints:

    getUser()
    getAccounts()
    getTransactions(accountId)
    getTransfers(accountId)

The class needs to be initialized with the Kontist username and password, e.g.

    const KontistClient = require("kontist-client");
    const kontist = new KontistClient({ user: process.env.KONTIST_USER, password: process.env.KONTIST_PASSWORD });
