#!/usr/bin/env node
'use strict';

require('dotenv').config()

const FORMAT_JSON = "json";
const FORMAT_QIF = "qif";

const KontistClient = require("./kontist-client");
const kontist = new KontistClient({ user: process.env.KONTIST_USER, password: process.env.KONTIST_PASSWORD });
const format = process.argv[2] || FORMAT_JSON;

/**
 * Format data as QIF or JSON.
 *
 * @param {*} data 
 * @param {string} format qif|json
 */
function convert(data, format) {

}

kontist.getAccounts()
    .then((account) => {
        return kontist.getTransactions(account[0].id);
    })
    .then((transactions) => {
        switch (format) {
            case FORMAT_JSON:
                return process.stdout.write(JSON.stringify(transactions, null, 4));
            case FORMAT_QIF:
                const qif = require('qif-writer');
                const data = transactions.map((row) => ({
                    date: new Date(row.date).toLocaleDateString("en-US"),
                    amount: row.amount,
                    payee: row.name,
                    memo: row.purpose
                }));
                qif.write(data, { type: 'Bank' });
                return
            default:
                throw new Error("Unknown format " + format);
        }
    });
